@@ -6,8 +6,9 @@ use warnings;
 use CPAN::Changes::Release;
 use Scalar::Util ();
 use version      ();
+use Encode qw(decode FB_CROAK LEAVE_SRC);
 
-our $VERSION = '0.30';
+our $VERSION = '0.400001';
 
 # From DateTime::Format::W3CDTF
 our $W3CDTF_REGEX = qr{(\d\d\d\d) # Year
@@ -45,11 +46,16 @@ sub new {
 sub load {
     my ( $class, $file, @args ) = @_;
 
-    open( my $fh, '<', $file ) or die $!;
-    my $changes = $class->load_string( do { local $/; <$fh>; }, @args );
-    close( $fh );
+    open( my $fh, '<:raw', $file ) or die $!;
 
-    return $changes;
+    my $content = do { local $/; <$fh> };
+
+    close $fh;
+
+    # if it's valid UTF-8, decode that.  otherwise, assume latin 1 and leave it.
+    eval { $content = decode('UTF-8', $content, FB_CROAK | LEAVE_SRC) };
+
+    return $class->load_string( $content, @args );
 }
 
 sub load_string {
@@ -135,9 +141,12 @@ sub load_string {
                 }
 
                 # clean date from note
-                $n =~ s{^$match\s*}{};
+                $n =~ s{^\Q$match\E\s*}{};
             }
 
+            undef $d unless length $d;
+            undef $n unless length $n;
+
             push @releases,
                 CPAN::Changes::Release->new(
                 version      => $v,
@@ -151,7 +160,7 @@ sub load_string {
         }
 
         # Grouping
-        if ( $l =~ m{^\s+\[\s*(.+?)\s*\]\s*$} ) {
+        if ( $l =~ m{^\s+\[\s*([^\[\]]+?)\s*\]\s*$} ) {
             $ingroup = $1;
             $releases[ -1 ]->add_group( $1 );
             next;
@@ -289,6 +298,7 @@ sub serialize {
     @r = reverse @r unless $args{reverse};  # not a typo!
 
     $output .= $_->serialize( %release_args ) for @r;
+    $output =~ s/\n\n+\z/\n/;
 
     return $output;
 }
